@@ -1924,7 +1924,7 @@ fastcgi_request_done:
 			request_body_fd = -2;
 
 			if (UNEXPECTED(EG(exit_status) == 255)) {
-				if (CGIG(error_header) && *CGIG(error_header)) {
+				if (CGIG(error_header) && *CGIG(error_header) && !SG(headers_sent)) {
 					sapi_header_line ctr = {0};
 
 					ctr.line = CGIG(error_header);
